import json
from datetime import datetime
from django.db import models

# from esi.webapp.models.wp import WpEsiTagNews
from .wp import WpEsiMedia, WpEsiEntity, WpEsiType, WpEsiRegion, WpEsiNewsEntity, WpEsiNews, WpEsiRadar, WpEsiIndustry, \
    WpEsiFunction, WpEsiTechnology, WpEsiTag, WpEsiNewsFunction, WpEsiNewsIndustry, WpEsiNewsRadar, \
    WpEsiTechnologyNews, WpEsiTagNews


class News(models.Model):
    title = models.CharField(max_length=255, default=None, null=True, blank=True)
    url = models.TextField(max_length=2083, default=None, null=True, blank=True)
    description = models.TextField(default=None, null=True, blank=True)
    text = models.TextField(default=None, null=True, blank=True)
    media_id = models.IntegerField(default=None, null=True, blank=True)
    type_id = models.IntegerField(default=None, null=True, blank=True)
    region_id = models.IntegerField(default=None, null=True, blank=True)
    post_id = models.BigIntegerField(default=None, null=True, blank=True)
    publish_date = models.DateTimeField(default=datetime.now, null=True, blank=True)
    record_date = models.DateTimeField(default=None, null=True, blank=True)

    company_id = models.BigIntegerField(default=None, null=True, blank=True)
    is_accepted = models.BooleanField(default=False)

    radar_id = models.CharField(max_length=256, default=None, null=True, blank=True)
    industry_id = models.CharField(max_length=255, default=None, null=True, blank=True)
    function_id = models.CharField(max_length=255, default=None, null=True, blank=True)
    technology_id = models.CharField(max_length=255, default=None, null=True, blank=True)
    tags_id = models.TextField(default=None, null=True, blank=True)

    temp_tags = models.TextField(default=None, null=True, blank=True)

    class Meta:
        db_table = 'wp_esi_news_accept'

    def __str__(self):
        return self.title

    def get_publish_date(self):
        return self.publish_date.date()

    def get_tags(self):
        if self.tags_id:
            tags = json.loads(self.tags_id)
            return WpEsiTag.objects.filter(id__in=tags)
        return None

    def get_tags_json(self):
        tags = self.get_tags()
        if tags:
            return json.dumps([{'text': i.name, 'value': i.id} for i in tags])
        return None

    def get_technology(self):
        if self.technology_id:
            return WpEsiTechnology.objects.filter(id__in=json.loads(self.technology_id))
        return None

    def get_technology_json(self):
        tech = self.get_technology()
        if tech:
            return json.dumps([{'text': i.name, 'value': i.id} for i in tech])
        return None

    def get_function(self):
        if self.function_id:
            return WpEsiFunction.objects.filter(id__in=json.loads(self.function_id))
        return None

    def get_function_json(self):
        func = self.get_function()
        if func:
            return json.dumps([{'text': i.name, 'value': i.id} for i in func])
        return None

    def get_industry(self):
        if self.industry_id:
            return WpEsiIndustry.objects.filter(id__in=json.loads(self.industry_id))
        return None

    def get_industry_json(self):
        ind = self.get_industry()
        if ind:
            return json.dumps([{'text': i.name, 'value': i.id} for i in ind])
        return None

    def get_radar(self):
        if self.radar_id:
            return WpEsiRadar.objects.get(id=self.radar_id)
        return None

    def get_media(self):
        return WpEsiMedia.objects.get(id=self.media_id)

    def get_type(self):
        return WpEsiType.objects.get(id=self.type_id)

    def get_region(self):
        return WpEsiRegion.objects.get(id=self.region_id)

    def get_entity(self):
        return WpEsiEntity.objects.get(id=self.company_id)

    def export_news(self):
        esi = WpEsiNews.objects.create(
            title=self.title,
            description=self.description,
            url=self.url,
            media_id=self.media_id,
            type_id=self.type_id,
            region_id=self.region_id,
            post_id=self.post_id,
            publish_date=self.publish_date,
            record_date=self.record_date
        )
        esi_entity = WpEsiNewsEntity.objects.create(
            news_id=esi.id,
            entity_id=self.company_id
        )
        self.is_accepted = True
        self.save()
        if self.radar_id:

            WpEsiNewsRadar.objects.bulk_create([WpEsiNewsRadar(news_id=esi.id, radar_id=i) for i in json.loads(self.radar_id)])

        if self.industry_id:
            industry = json.loads(self.industry_id)
            WpEsiNewsIndustry.objects.bulk_create([WpEsiNewsIndustry(news_id=esi.id, industry_id=i) for i in industry])

        if self.function_id:
            func = json.loads(self.function_id)
            WpEsiNewsFunction.objects.bulk_create([WpEsiNewsFunction(news_id=esi.id, function_id=i) for i in func])

        if self.technology_id:
            technology = json.loads(self.technology_id)
            WpEsiTechnologyNews.objects.bulk_create(WpEsiTechnologyNews(news_id=esi.id, technology_id=i) for i in technology)

        if self.tags_id:
            tags = json.loads(self.tags_id)
            WpEsiTagNews.objects.bulk_create(WpEsiTagNews(news_id=esi.id, tag_id=i) for i in tags)
