# -*- coding: utf-8 -*-
import scrapy
from scrapy.utils.project import get_project_settings
from scrapy_splash import SplashRequest
from w3lib.http import basic_auth_header
from pkgutil import get_data

from .base import BaseSpider
from ..items import ExaItem

api_key = get_project_settings().get('CRAWLERA_APIKEY')


class CbSpider(BaseSpider):
    name = "cb"
    allowed_domains = ["www.crunchbase.com"]
    handle_httpstatus_list = [470]
    # crawlera_enabled = True
    # crawlera_apikey = api_key
    co = 0

    def __init__(self, *args, **kwargs):
        self.LUA_SOURCE = get_data(
            'exa', 'scripts/crawlera.lua'
        ).decode('utf-8')
        super(CbSpider, self).__init__(*args, **kwargs)

    def start_requests(self):
        for i in self.companies(self.name):
            try:
                yield SplashRequest(url=i.url,
                                    callback=self.parse,
                                    endpoint='execute',
                                    meta={'company': i, 'post_id': 0},
                                    args={'wait': 5,
                                          'lua_source': self.LUA_SOURCE,
                                          'apikey': self.settings['CRAWLERA_APIKEY'],
                                          },
                                    # cache_args=['lua_source'],
                                    )
            except:
                pass

    def parse(self, response):
        print(response.body)
        rows = response.xpath(".//div[@class='grid-body']/div")
        company = response.meta['company']
        is_duplicate = False
        for i in rows:
            item = ExaItem()
            item['date'] = self.format_date(i.xpath("./div/div/field-formatter/span/@title").extract_first())
            item['title'] = i.xpath("./div/div/press-reference/div/div/span/span[2]/a/text()").extract_first().strip()
            item['url'] = i.xpath("./div/div/press-reference/div/div/span/span[2]/a/@href").extract_first()
            item.update(self.get_common_items(company))
            item['media_id'] = self._get_media(i)
            item['description'] = None
            item['post_id'] = response.meta['post_id']
            item['tags'] = None
            self.co += 1
            print(self.co)

            if self.pipeline.check_url(item['url']):
                is_duplicate = True
                if self.fresh:
                    break
            yield item
        # next_url = self._next_url(response.url)
        # if len(rows) != 0 and self.can_follow(next_url, is_duplicate):
        #     yield scrapy.Request(next_url, callback=self.parse, meta=response.meta)

    def _get_media(self, elem):
        media_name = elem.xpath("./td[contains(@class, 'article')]/span/text()").extract_first()
        media_url = elem.xpath("./td/a/@data_publisher").extract_first()
        query = "select * from wp_esi_media where name like '%{}%' or url like '%{}%'".format(media_name, media_url)
        media = self.pipeline.db.select(query)
        if len(media) == 0:
            media = self.pipeline.db.insert("INSERT INTO wp_esi_media (name, url) VALUES(%s, %s)", (media_name, media_url))
        else:
            media = media[0][0]
        return media

    def _next_url(self, url):
        pos = url.rfind('=') + 1
        next_page = int(url[pos:]) + 1
        return url[:pos] + str(next_page)
